package com.gic.demo.single.web.controller;

import com.alibaba.fastjson.JSON;
import com.gic.authcenter.sdk.GicAuthcenterManager;
import com.gic.authcenter.sdk.exception.NoTokenCacheException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * GIC 认证中心 SDK 测试
 *
 * @author zhurz
 */
@RestController
public class AuthcenterTestController {

    private Logger logger = LoggerFactory.getLogger(getClass());

    @Autowired
    private GicAuthcenterManager gicAuthcenterManager;

    /**
     * @return 获取 oauth2 登录 url
     */
    @RequestMapping("/get-oauth2-login-url")
    public String getOAuth2LoginUrl() {
        return gicAuthcenterManager.getAuthorizeUrl();
    }

    /**
     * oauth2 登录
     */
    @RequestMapping("/oauth2-login")
    public void oauth2Login(HttpServletResponse response) {
        try {
            response.sendRedirect(gicAuthcenterManager.getAuthorizeUrl());
        } catch (IOException e) {
            logger.warn(e.getMessage());
        }
    }

    /**
     * 接收授权 code
     *
     * @param code 授权 code
     * @return 用户详情
     */
    @RequestMapping("/authcenter-code-callback")
    public String authcenterCodeCallback(@RequestParam(name = "code") String code) {
        return JSON.toJSONString(gicAuthcenterManager.processCode(code));
    }

    /**
     * 获取用户详情
     *
     * @param id 用户 id
     * @return 用户详情
     */
    @RequestMapping("/get-user-details")
    public String getUserDetails(@RequestParam(name = "id") Integer id) {
        try {
            return JSON.toJSONString(gicAuthcenterManager.getUserDetails(id));
        } catch (NoTokenCacheException e) {
            return "无 token 缓存";
        }
    }

}
